# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import test_access
from . import test_auto_status
from . import test_contract
from . import test_calendar_sync
from . import test_mail_activity_plan
from . import test_resource
from . import test_hr_contract_history_groupby
from . import test_attendances
